==> nomachine-8.12.12-1-x86_64.pkg.tar.zst: NX/lib/perl/nxserver/NXReverseClientDaemon.pm <==
############################################################################
#                                                                          #
#  Copyright (c) 2001, 2024 NoMachine, http://www.nomachine.com.           #
#                                                                          #
#  NXSERVER, NX protocol compression and NX extensions to this software    #
#  are copyright of NoMachine. Redistribution and use of the present       #
#  software is allowed according to terms specified in the file LICENSE    #
#  which comes in the source distribution.                                 #
#                                                                          #
#  Check http://www.nomachine.com/licensing.html for applicability.        #
#                                                                          #
#  NX and NoMachine are trademarks of NoMachine S.a.r.l.                   #
#                                                                          #
#  All rights reserved.                                                    #
#                                                                          #
############################################################################
package NXReverseClientDaemon;no warnings;((%monitor)=());((%monitorFD)=());sub 
handleConnection{(my $fd=shift (@_));(my $request=shift (@_));Logger::debug (((
"\x4e\x58\x52\x65\x76\x65\x72\x73\x65\x43\x6c\x69\x65\x6e\x74\x44\x61\x65\x6d\x6f\x6e\x3a\x20\x48\x61\x6e\x64\x6c\x69\x6e\x67\x20\x63\x6f\x6e\x6e\x65\x63\x74\x69\x6f\x6e\x20\x66\x72\x6f\x6d\x20\x72\x65\x76\x65\x72\x73\x65\x20\x43\x4d\x20\x27"
.$request)."\x27\x2e"));if (($request=~ /Reverse connection running for uuid=(.*) / )
){(my $uuid=$1);($monitor{$uuid}=$fd);($monitorFD{$fd}=$uuid);(my $caption=(
$uuid.
"\x20\x72\x65\x76\x65\x72\x73\x65\x20\x43\x4d\x20\x6d\x6f\x6e\x69\x74\x6f\x72"))
;(my $callback=
"\x4e\x58\x52\x65\x76\x65\x72\x73\x65\x43\x6c\x69\x65\x6e\x74\x44\x61\x65\x6d\x6f\x6e\x3a\x3a\x63\x61\x6c\x6c\x62\x61\x63\x6b"
);Common::NXSelector::changeCallback ($fd,$caption,$callback);
NXServerDaemon::removeFdFromSelector ($fd);return ((0x12c1+ 1099-0x170b));}
Logger::warning (((
"\x4e\x58\x52\x65\x76\x65\x72\x73\x65\x43\x6c\x69\x65\x6e\x74\x44\x61\x65\x6d\x6f\x6e\x3a\x20\x43\x61\x6e\x6e\x6f\x74\x20\x68\x61\x6e\x64\x6c\x65\x20\x72\x65\x76\x65\x72\x73\x65\x20\x63\x6f\x6e\x6e\x65\x63\x74\x69\x6f\x6e\x20\x6d\x6f\x6e\x69\x74\x6f\x72\x20\x72\x65\x71\x75\x65\x73\x74\x20\x27"
.$request)."\x27\x2e"));return ((0x093c+ 369-0x0aad));}sub callback{(my $fd=
shift (@_));(my $uuid=$monitorFD{$fd});my ($buffer);(my $bytes=main::nxread ($fd
,(\$buffer),65536));if (($bytes>(0x01f0+ 568-0x0428))){Logger::warning (((((((
"\x4e\x58\x52\x65\x76\x65\x72\x73\x65\x43\x6c\x69\x65\x6e\x74\x44\x61\x65\x6d\x6f\x6e\x3a\x20\x52\x65\x61\x64\x20\x27"
.$buffer).
"\x27\x20\x66\x72\x6f\x6d\x20\x74\x68\x65\x20\x63\x6f\x6e\x6e\x65\x63\x74\x69\x6f\x6e\x20\x6d\x6f\x6e\x69\x74\x6f\x72\x20\x27"
).$uuid)."\x27\x20\x46\x44\x23").$fd)."\x2e"));}else{Logger::debug (((((
"\x4e\x58\x52\x65\x76\x65\x72\x73\x65\x43\x6c\x69\x65\x6e\x74\x44\x61\x65\x6d\x6f\x6e\x3a\x20\x43\x6f\x6e\x6e\x65\x63\x74\x69\x6f\x6e\x20\x74\x6f\x20\x63\x6f\x6e\x6e\x65\x63\x74\x69\x6f\x6e\x20\x6d\x6f\x6e\x69\x74\x6f\x72\x20\x27"
.$uuid)."\x27\x20\x63\x6c\x6f\x73\x65\x64\x20\x46\x44\x23").$fd)."\x2e"));
Common::NXSelector::removeFromGlobalSelector ($fd);main::nxclose ($fd);if ((
$monitor{$uuid}!=$fd)){Logger::debug (
"\x4e\x58\x52\x65\x76\x65\x72\x73\x65\x43\x6c\x69\x65\x6e\x74\x44\x61\x65\x6d\x6f\x6e\x3a\x20\x4e\x65\x77\x20\x63\x6f\x6e\x6e\x65\x63\x74\x69\x6f\x6e\x20\x6d\x6f\x6e\x69\x74\x6f\x72\x20\x61\x6c\x72\x65\x61\x64\x79\x20\x72\x75\x6e\x6e\x69\x6e\x67\x2e"
);return ((0x0450+ 6102-0x1c26));}__setUnreachable ($uuid);($monitor{$uuid}=
undef);($monitorFD{$fd}=undef);delete ($monitor{$uuid});delete ($monitorFD{$fd})
;if ((not (NXServerDaemon::isTerminateMode ()))){
NXConnectionMonitor::propagateMap ();}}}sub checkStatus{(my $uuid=shift (@_));(my $connection
=$monitor{$uuid});if (defined ($monitor{$uuid})){Logger::debug (((((
"\x4e\x58\x52\x65\x76\x65\x72\x73\x65\x43\x6c\x69\x65\x6e\x74\x44\x61\x65\x6d\x6f\x6e\x3a\x20\x52\x65\x76\x65\x72\x73\x65\x20\x43\x4d\x20\x27"
.$uuid).
"\x27\x20\x69\x73\x20\x63\x6f\x6e\x6e\x65\x63\x74\x65\x64\x20\x77\x69\x74\x68\x20\x46\x44"
).$connection)."\x2e"));}else{Logger::debug (((
"\x4e\x58\x52\x65\x76\x65\x72\x73\x65\x43\x6c\x69\x65\x6e\x74\x44\x61\x65\x6d\x6f\x6e\x3a\x20\x52\x65\x76\x65\x72\x73\x65\x20\x43\x4d\x20\x27"
.$uuid).
"\x27\x20\x69\x6e\x20\x6e\x6f\x74\x20\x63\x6f\x6e\x6e\x65\x63\x74\x65\x64\x2e"))
;__setUnreachable ($uuid);}}sub __setUnreachable{(my $uuid=shift (@_));(my (
@keys)=());(my (@args)=$uuid);(my $timeout=(-(0x134b+ 898-0x16cc)));
main::nxrequire ("\x4e\x58\x52\x65\x64\x69\x73\x53\x63\x72\x69\x70\x74");return 
(NXRedisScript::executeScript (
"\x73\x65\x74\x55\x6e\x72\x65\x61\x63\x68\x61\x62\x6c\x65",(\@keys),(\@args),
$timeout));}return ((0x1d8b+ 1914-0x2504));

==> nomachine-8.13.1-1-x86_64.pkg.tar.zst: NX/lib/perl/nxserver/NXReverseClientDaemon.pm <==
############################################################################
#                                                                          #
#  Copyright (c) 2001, 2024 NoMachine, http://www.nomachine.com.           #
#                                                                          #
#  NXSERVER, NX protocol compression and NX extensions to this software    #
#  are copyright of NoMachine. Redistribution and use of the present       #
#  software is allowed according to terms specified in the file LICENSE    #
#  which comes in the source distribution.                                 #
#                                                                          #
#  Check http://www.nomachine.com/licensing.html for applicability.        #
#                                                                          #
#  NX and NoMachine are trademarks of NoMachine S.a.r.l.                   #
#                                                                          #
#  All rights reserved.                                                    #
#                                                                          #
############################################################################
package NXReverseClientDaemon;no warnings;((%monitor)=());((%monitorFD)=());sub 
handleConnection{(my $fd=shift (@_));(my $request=shift (@_));Logger::debug (((
"\x4e\x58\x52\x65\x76\x65\x72\x73\x65\x43\x6c\x69\x65\x6e\x74\x44\x61\x65\x6d\x6f\x6e\x3a\x20\x48\x61\x6e\x64\x6c\x69\x6e\x67\x20\x63\x6f\x6e\x6e\x65\x63\x74\x69\x6f\x6e\x20\x66\x72\x6f\x6d\x20\x72\x65\x76\x65\x72\x73\x65\x20\x43\x4d\x20\x27"
.$request)."\x27\x2e"));if (($request=~ /Reverse connection running for uuid=(.*) / )
){(my $uuid=$1);($monitor{$uuid}=$fd);($monitorFD{$fd}=$uuid);(my $caption=(
$uuid.
"\x20\x72\x65\x76\x65\x72\x73\x65\x20\x43\x4d\x20\x6d\x6f\x6e\x69\x74\x6f\x72"))
;(my $callback=
"\x4e\x58\x52\x65\x76\x65\x72\x73\x65\x43\x6c\x69\x65\x6e\x74\x44\x61\x65\x6d\x6f\x6e\x3a\x3a\x63\x61\x6c\x6c\x62\x61\x63\x6b"
);Common::NXSelector::changeCallback ($fd,$caption,$callback);
NXServerDaemon::removeFdFromSelector ($fd);return ((0x0998+ 4316-0x1a73));}
Logger::warning (((
"\x4e\x58\x52\x65\x76\x65\x72\x73\x65\x43\x6c\x69\x65\x6e\x74\x44\x61\x65\x6d\x6f\x6e\x3a\x20\x43\x61\x6e\x6e\x6f\x74\x20\x68\x61\x6e\x64\x6c\x65\x20\x72\x65\x76\x65\x72\x73\x65\x20\x63\x6f\x6e\x6e\x65\x63\x74\x69\x6f\x6e\x20\x6d\x6f\x6e\x69\x74\x6f\x72\x20\x72\x65\x71\x75\x65\x73\x74\x20\x27"
.$request)."\x27\x2e"));return ((0x051a+  83-0x056d));}sub callback{(my $fd=
shift (@_));(my $uuid=$monitorFD{$fd});my ($buffer);(my $bytes=main::nxread ($fd
,(\$buffer),65536));if (($bytes>(0x03d3+  35-0x03f6))){Logger::warning (((((((
"\x4e\x58\x52\x65\x76\x65\x72\x73\x65\x43\x6c\x69\x65\x6e\x74\x44\x61\x65\x6d\x6f\x6e\x3a\x20\x52\x65\x61\x64\x20\x27"
.$buffer).
"\x27\x20\x66\x72\x6f\x6d\x20\x74\x68\x65\x20\x63\x6f\x6e\x6e\x65\x63\x74\x69\x6f\x6e\x20\x6d\x6f\x6e\x69\x74\x6f\x72\x20\x27"
).$uuid)."\x27\x20\x46\x44\x23").$fd)."\x2e"));}else{Logger::debug (((((
"\x4e\x58\x52\x65\x76\x65\x72\x73\x65\x43\x6c\x69\x65\x6e\x74\x44\x61\x65\x6d\x6f\x6e\x3a\x20\x43\x6f\x6e\x6e\x65\x63\x74\x69\x6f\x6e\x20\x74\x6f\x20\x63\x6f\x6e\x6e\x65\x63\x74\x69\x6f\x6e\x20\x6d\x6f\x6e\x69\x74\x6f\x72\x20\x27"
.$uuid)."\x27\x20\x63\x6c\x6f\x73\x65\x64\x20\x46\x44\x23").$fd)."\x2e"));
Common::NXSelector::removeFromGlobalSelector ($fd);main::nxclose ($fd);if ((
$monitor{$uuid}!=$fd)){Logger::debug (
"\x4e\x58\x52\x65\x76\x65\x72\x73\x65\x43\x6c\x69\x65\x6e\x74\x44\x61\x65\x6d\x6f\x6e\x3a\x20\x4e\x65\x77\x20\x63\x6f\x6e\x6e\x65\x63\x74\x69\x6f\x6e\x20\x6d\x6f\x6e\x69\x74\x6f\x72\x20\x61\x6c\x72\x65\x61\x64\x79\x20\x72\x75\x6e\x6e\x69\x6e\x67\x2e"
);return ((0x04eb+ 7155-0x20de));}__setUnreachable ($uuid);($monitor{$uuid}=
undef);($monitorFD{$fd}=undef);delete ($monitor{$uuid});delete ($monitorFD{$fd})
;if ((not (NXServerDaemon::isTerminateMode ()))){
NXConnectionMonitor::propagateMap ();}}}sub checkStatus{(my $uuid=shift (@_));(my $connection
=$monitor{$uuid});if (defined ($monitor{$uuid})){Logger::debug (((((
"\x4e\x58\x52\x65\x76\x65\x72\x73\x65\x43\x6c\x69\x65\x6e\x74\x44\x61\x65\x6d\x6f\x6e\x3a\x20\x52\x65\x76\x65\x72\x73\x65\x20\x43\x4d\x20\x27"
.$uuid).
"\x27\x20\x69\x73\x20\x63\x6f\x6e\x6e\x65\x63\x74\x65\x64\x20\x77\x69\x74\x68\x20\x46\x44"
).$connection)."\x2e"));}else{Logger::debug (((
"\x4e\x58\x52\x65\x76\x65\x72\x73\x65\x43\x6c\x69\x65\x6e\x74\x44\x61\x65\x6d\x6f\x6e\x3a\x20\x52\x65\x76\x65\x72\x73\x65\x20\x43\x4d\x20\x27"
.$uuid).
"\x27\x20\x69\x6e\x20\x6e\x6f\x74\x20\x63\x6f\x6e\x6e\x65\x63\x74\x65\x64\x2e"))
;__setUnreachable ($uuid);}}sub __setUnreachable{(my $uuid=shift (@_));(my (
@keys)=());(my (@args)=$uuid);(my $timeout=(-(0x15a1+ 999-0x1987)));
main::nxrequire ("\x4e\x58\x52\x65\x64\x69\x73\x53\x63\x72\x69\x70\x74");return 
(NXRedisScript::executeScript (
"\x73\x65\x74\x55\x6e\x72\x65\x61\x63\x68\x61\x62\x6c\x65",(\@keys),(\@args),
$timeout));}return ((0x1962+ 896-0x1ce1));
